nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

DcCtrl

Struct DcCtrl 

#[repr(transparent)]
pub struct DcCtrl(pub u32);
DC Filter Control

Tuple Fields

0: u32

Implementations

Source

impl DcCtrl

pub const fn dcpole(&self) -> Dcpole

DC block filter

pub const fn set_dcpole(&mut self, val: Dcpole)

DC block filter

pub const fn dcgain(&self) -> u8

Fine gain adjustment in the form of a number of bits to downshift.

pub const fn set_dcgain(&mut self, val: u8)

Fine gain adjustment in the form of a number of bits to downshift.

pub const fn saturateat16bit(&self) -> Saturateat16bit

Selects 16-bit saturation.

pub const fn set_saturateat16bit(&mut self, val: Saturateat16bit)

Selects 16-bit saturation.

pub const fn signextend(&self) -> Signextend

Sign extend.

pub const fn set_signextend(&mut self, val: Signextend)

Sign extend.