nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Hwvadst10

Struct Hwvadst10 

#[repr(transparent)]
pub struct Hwvadst10(pub u32);
HWVAD control register

Tuple Fields

0: u32

Implementations

Source

impl Hwvadst10

pub const fn st10(&self) -> St10

1’ means enter stage 1 of VAD, ie a sound change has been detected and the HWVAD is being allowed to settle. Use 0 when changing back to detection mode. Allow several milliseconds in stage 1 for settling.

pub const fn set_st10(&mut self, val: St10)

1’ means enter stage 1 of VAD, ie a sound change has been detected and the HWVAD is being allowed to settle. Use 0 when changing back to detection mode. Allow several milliseconds in stage 1 for settling.