nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Osr

Struct Osr 

#[repr(transparent)]
pub struct Osr(pub u32);
CIC Filter decimation rate

Tuple Fields

0: u32

Implementations

Source

impl Osr

pub const fn osr(&self) -> u8

Selects the oversample rate for the related input channel.

pub const fn set_osr(&mut self, val: u8)

Selects the oversample rate for the related input channel.