nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

PhyCtrl

Struct PhyCtrl 

#[repr(transparent)]
pub struct PhyCtrl(pub u32);
Phy Ctrl

Tuple Fields

0: u32

Implementations

Source

impl PhyCtrl

pub const fn phy_fall(&self) -> PhyFall

Capture DMIC on Falling edge (0 means on rising)

pub const fn set_phy_fall(&mut self, val: PhyFall)

Capture DMIC on Falling edge (0 means on rising)

pub const fn phy_half(&self) -> PhyHalf

Use Half rate sampling (ie Clock to dmic is sent at half the speed than the decimator is providing)

pub const fn set_phy_half(&mut self, val: PhyHalf)

Use Half rate sampling (ie Clock to dmic is sent at half the speed than the decimator is providing)