#[repr(transparent)]pub struct PhyCtrl(pub u32);Expand description
Phy Ctrl
Tuple Fields
0: u32Implementations
Sourceimpl PhyCtrl
impl PhyCtrl
Sourcepub const fn set_phy_fall(&mut self, val: PhyFall)
pub const fn set_phy_fall(&mut self, val: PhyFall)
Capture DMIC on Falling edge (0 means on rising)
Sourcepub const fn phy_half(&self) -> PhyHalf
pub const fn phy_half(&self) -> PhyHalf
Use Half rate sampling (ie Clock to dmic is sent at half the speed than the decimator is providing)
Sourcepub const fn set_phy_half(&mut self, val: PhyHalf)
pub const fn set_phy_half(&mut self, val: PhyHalf)
Use Half rate sampling (ie Clock to dmic is sent at half the speed than the decimator is providing)